# Scallop - Robustness of single-cell clustering solutions
Scallop is a module for the evaluation of single-cell clustering solutions. 
It allows users to assess the quality of clustering using different
algorithms and parameter choices. 

Scallop provides users with a cell-wise robustness score based on bootstrap experiments, 
and a versatile plotting toolkit for visualization purposes. 

Scallop is meant to be used 
with annData objects from Scanpy. 